# 🦜🔗🔍 Tinylang

## This is deprecated, use [OpenAI Assistants](https://platform.openai.com/docs/assistants/overview) instead.

[Documentation](https://astelmach01.github.io/tinylang/)

Make working with LLMs insanely simpler and easier than ever before.

## What is tinylang?
A hackable and simpler Langchain.

Langchain can be very cumbersome and annoying to work with. It's too big, complicated, and shoves pre-made prompts down your throat.

With tinylang, everything is intuitive and customizable, following most of the Langchain API.




- get base LLMs working (OpenAI, Gemini, Claude)
- streaming
- conversation history
- function calling
